@@ -12,8 +12,8 @@
 # flake8: noqa
 from __future__ import absolute_import
 
-from .csrf import CsrfProtect
+from .csrf import CSRFProtect, CsrfProtect
 from .form import FlaskForm, Form
 from .recaptcha import *
 
-__version__ = '0.13.1'
+__version__ = '0.14.2'
